@@ -4,7 +4,7 @@ Main interface for kms service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_kms import (
         Client,
         KMSClient,
@@ -14,10 +14,8 @@ Usage::
         ListKeysPaginator,
     )
 
-    session = boto3.Session()
-
-    client: KMSClient = boto3.client("kms")
-    session_client: KMSClient = session.client("kms")
+    session = Session()
+    client: KMSClient = session.client("kms")
 
     list_aliases_paginator: ListAliasesPaginator = client.get_paginator("list_aliases")
     list_grants_paginator: ListGrantsPaginator = client.get_paginator("list_grants")
