@@ -30,6 +30,7 @@ from .literals import (
     GrantOperationType,
     KeySpecType,
     KeyUsageTypeType,
+    MacAlgorithmSpecType,
     MessageTypeType,
     OriginTypeType,
     SigningAlgorithmSpecType,
@@ -53,6 +54,7 @@ from .type_defs import (
     GenerateDataKeyPairWithoutPlaintextResponseTypeDef,
     GenerateDataKeyResponseTypeDef,
     GenerateDataKeyWithoutPlaintextResponseTypeDef,
+    GenerateMacResponseTypeDef,
     GenerateRandomResponseTypeDef,
     GetKeyPolicyResponseTypeDef,
     GetKeyRotationStatusResponseTypeDef,
@@ -69,6 +71,7 @@ from .type_defs import (
     ScheduleKeyDeletionResponseTypeDef,
     SignResponseTypeDef,
     TagTypeDef,
+    VerifyMacResponseTypeDef,
     VerifyResponseTypeDef,
 )
 
@@ -116,6 +119,7 @@ class Exceptions:
     InvalidKeyUsageException: Type[BotocoreClientError]
     InvalidMarkerException: Type[BotocoreClientError]
     KMSInternalException: Type[BotocoreClientError]
+    KMSInvalidMacException: Type[BotocoreClientError]
     KMSInvalidSignatureException: Type[BotocoreClientError]
     KMSInvalidStateException: Type[BotocoreClientError]
     KeyUnavailableException: Type[BotocoreClientError]
@@ -321,7 +325,7 @@ class KMSClient(BaseClient):
         """
         Disables [automatic rotation of the key
         material](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-
-        keys.html)_ for the specified symmetric KMS key.
+        keys.html)_ for the specified symmetric encryption KMS key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.disable_key_rotation)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#disable_key_rotation)
@@ -349,7 +353,7 @@ class KMSClient(BaseClient):
         """
         Enables [automatic rotation of the key
         material](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-
-        keys.html)_ for the specified symmetric KMS key.
+        keys.html)_ for the specified symmetric encryption KMS key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.enable_key_rotation)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#enable_key_rotation)
@@ -365,7 +369,7 @@ class KMSClient(BaseClient):
         EncryptionAlgorithm: EncryptionAlgorithmSpecType = ...
     ) -> EncryptResponseTypeDef:
         """
-        Encrypts plaintext into ciphertext by using a KMS key.
+        Encrypts plaintext of up to 4,096 bytes using a KMS key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.encrypt)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#encrypt)
@@ -381,7 +385,7 @@ class KMSClient(BaseClient):
         GrantTokens: Sequence[str] = ...
     ) -> GenerateDataKeyResponseTypeDef:
         """
-        Generates a unique symmetric data key for client-side encryption.
+        Returns a unique symmetric data key for use outside of KMS.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.generate_data_key)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#generate_data_key)
@@ -396,7 +400,7 @@ class KMSClient(BaseClient):
         GrantTokens: Sequence[str] = ...
     ) -> GenerateDataKeyPairResponseTypeDef:
         """
-        Generates a unique asymmetric data key pair.
+        Returns a unique asymmetric data key pair for use outside of KMS.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.generate_data_key_pair)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#generate_data_key_pair)
@@ -411,7 +415,7 @@ class KMSClient(BaseClient):
         GrantTokens: Sequence[str] = ...
     ) -> GenerateDataKeyPairWithoutPlaintextResponseTypeDef:
         """
-        Generates a unique asymmetric data key pair.
+        Returns a unique asymmetric data key pair for use outside of KMS.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.generate_data_key_pair_without_plaintext)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#generate_data_key_pair_without_plaintext)
@@ -427,12 +431,28 @@ class KMSClient(BaseClient):
         GrantTokens: Sequence[str] = ...
     ) -> GenerateDataKeyWithoutPlaintextResponseTypeDef:
         """
-        Generates a unique symmetric data key.
+        Returns a unique symmetric data key for use outside of KMS.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.generate_data_key_without_plaintext)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#generate_data_key_without_plaintext)
         """
 
+    def generate_mac(
+        self,
+        *,
+        Message: Union[str, bytes, IO[Any], StreamingBody],
+        KeyId: str,
+        MacAlgorithm: MacAlgorithmSpecType,
+        GrantTokens: Sequence[str] = ...
+    ) -> GenerateMacResponseTypeDef:
+        """
+        Generates a hash-based message authentication code (HMAC) for a message using an
+        HMAC KMS key and a MAC algorithm that the key supports.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.generate_mac)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#generate_mac)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -483,8 +503,8 @@ class KMSClient(BaseClient):
         WrappingKeySpec: Literal["RSA_2048"]
     ) -> GetParametersForImportResponseTypeDef:
         """
-        Returns the items you need to import key material into a symmetric, customer
-        managed KMS key.
+        Returns the items you need to import key material into a symmetric encryption
+        KMS key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.get_parameters_for_import)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#get_parameters_for_import)
@@ -510,8 +530,8 @@ class KMSClient(BaseClient):
         ExpirationModel: ExpirationModelTypeType = ...
     ) -> Dict[str, Any]:
         """
-        Imports key material into an existing symmetric KMS KMS key that was created
-        without key material.
+        Imports key material into an existing symmetric encryption KMS key that was
+        created without key material.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.import_key_material)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#import_key_material)
@@ -671,8 +691,8 @@ class KMSClient(BaseClient):
     ) -> SignResponseTypeDef:
         """
         Creates a [digital signature](https://en.wikipedia.org/wiki/Digital_signature)_
-        for a message or message digest by using the private key in an asymmetric KMS
-        key.
+        for a message or message digest by using the private key in an asymmetric
+        signing KMS key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.sign)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#sign)
@@ -754,6 +774,23 @@ class KMSClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#verify)
         """
 
+    def verify_mac(
+        self,
+        *,
+        Message: Union[str, bytes, IO[Any], StreamingBody],
+        KeyId: str,
+        MacAlgorithm: MacAlgorithmSpecType,
+        Mac: Union[str, bytes, IO[Any], StreamingBody],
+        GrantTokens: Sequence[str] = ...
+    ) -> VerifyMacResponseTypeDef:
+        """
+        Verifies the hash-based message authentication code (HMAC) for a specified
+        message, HMAC KMS key, and MAC algorithm.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#KMS.Client.verify_mac)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kms/client/#verify_mac)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_aliases"]) -> ListAliasesPaginator:
         """
