@@ -31,6 +31,7 @@ from .literals import (
     KeySpecType,
     KeyStateType,
     KeyUsageTypeType,
+    MacAlgorithmSpecType,
     MessageTypeType,
     MultiRegionKeyTypeType,
     OriginTypeType,
@@ -84,6 +85,8 @@ __all__ = (
     "GenerateDataKeyResponseTypeDef",
     "GenerateDataKeyWithoutPlaintextRequestRequestTypeDef",
     "GenerateDataKeyWithoutPlaintextResponseTypeDef",
+    "GenerateMacRequestRequestTypeDef",
+    "GenerateMacResponseTypeDef",
     "GenerateRandomRequestRequestTypeDef",
     "GenerateRandomResponseTypeDef",
     "GetKeyPolicyRequestRequestTypeDef",
@@ -136,6 +139,8 @@ __all__ = (
     "UpdateCustomKeyStoreRequestRequestTypeDef",
     "UpdateKeyDescriptionRequestRequestTypeDef",
     "UpdatePrimaryRegionRequestRequestTypeDef",
+    "VerifyMacRequestRequestTypeDef",
+    "VerifyMacResponseTypeDef",
     "VerifyRequestRequestTypeDef",
     "VerifyResponseTypeDef",
 )
@@ -587,6 +592,39 @@ GenerateDataKeyWithoutPlaintextResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredGenerateMacRequestRequestTypeDef = TypedDict(
+    "_RequiredGenerateMacRequestRequestTypeDef",
+    {
+        "Message": Union[str, bytes, IO[Any], StreamingBody],
+        "KeyId": str,
+        "MacAlgorithm": MacAlgorithmSpecType,
+    },
+)
+_OptionalGenerateMacRequestRequestTypeDef = TypedDict(
+    "_OptionalGenerateMacRequestRequestTypeDef",
+    {
+        "GrantTokens": Sequence[str],
+    },
+    total=False,
+)
+
+
+class GenerateMacRequestRequestTypeDef(
+    _RequiredGenerateMacRequestRequestTypeDef, _OptionalGenerateMacRequestRequestTypeDef
+):
+    pass
+
+
+GenerateMacResponseTypeDef = TypedDict(
+    "GenerateMacResponseTypeDef",
+    {
+        "Mac": bytes,
+        "MacAlgorithm": MacAlgorithmSpecType,
+        "KeyId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GenerateRandomRequestRequestTypeDef = TypedDict(
     "GenerateRandomRequestRequestTypeDef",
     {
@@ -778,6 +816,7 @@ _OptionalKeyMetadataTypeDef = TypedDict(
         "MultiRegion": bool,
         "MultiRegionConfiguration": "MultiRegionConfigurationTypeDef",
         "PendingDeletionWindowInDays": int,
+        "MacAlgorithms": List[MacAlgorithmSpecType],
     },
     total=False,
 )
@@ -1304,6 +1343,40 @@ UpdatePrimaryRegionRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredVerifyMacRequestRequestTypeDef = TypedDict(
+    "_RequiredVerifyMacRequestRequestTypeDef",
+    {
+        "Message": Union[str, bytes, IO[Any], StreamingBody],
+        "KeyId": str,
+        "MacAlgorithm": MacAlgorithmSpecType,
+        "Mac": Union[str, bytes, IO[Any], StreamingBody],
+    },
+)
+_OptionalVerifyMacRequestRequestTypeDef = TypedDict(
+    "_OptionalVerifyMacRequestRequestTypeDef",
+    {
+        "GrantTokens": Sequence[str],
+    },
+    total=False,
+)
+
+
+class VerifyMacRequestRequestTypeDef(
+    _RequiredVerifyMacRequestRequestTypeDef, _OptionalVerifyMacRequestRequestTypeDef
+):
+    pass
+
+
+VerifyMacResponseTypeDef = TypedDict(
+    "VerifyMacResponseTypeDef",
+    {
+        "KeyId": str,
+        "MacValid": bool,
+        "MacAlgorithm": MacAlgorithmSpecType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredVerifyRequestRequestTypeDef = TypedDict(
     "_RequiredVerifyRequestRequestTypeDef",
     {
